ChangeSet 1.808.2.26, 2002/10/28 12:02:49-08:00, david-b@pacbell.net

[PATCH] Zaurus support for usbnet

> This is a patch against 2.4.20-pre11, because i can't use the 2.5.44 (kernel
> freeze a boot time). The second patch is a incremental patch for the latest
> 2.5 kernel.

Cool!  Greg, 2.5 version (attached) looks fine to me.  If it
applies against your BK repository, please merge it.

The 2.4.20 version looks to be using an older version of the
usbnet driver, so please don't merge that one.  I'll resync in
a while.

By the way, I found out that it's not "the www.handhelds.org"
kernel but the standard ARM kernels (like 2.4.29-rmk2) that
have the "usb-eth" driver for the SA-1100.  They're going to
need similar changes (switch endpoints for pxa250 versions).

Time to actually look at the endpoint descriptors, maybe ... :)


diff -Nru a/drivers/usb/net/usbnet.c b/drivers/usb/net/usbnet.c
--- a/drivers/usb/net/usbnet.c	Mon Oct 28 13:51:21 2002
+++ b/drivers/usb/net/usbnet.c	Mon Oct 28 13:51:21 2002
@@ -1347,13 +1347,20 @@
 	return skb;
 }
 
-static const struct driver_info	zaurus_info = {
-	.description =	"Sharp Zaurus",
+static const struct driver_info	zaurus_sl5x00_info = {
+	.description =	"Sharp Zaurus SL-5x00",
 	.tx_fixup = 	zaurus_tx_fixup,
 
 	.in = 2, .out = 1,
 	.epsize = 64,
 };
+static const struct driver_info	zaurus_sla300_info = {
+	.description =	"Sharp Zaurus SL-A300",
+	.tx_fixup = 	zaurus_tx_fixup,
+
+	.in = 1, .out = 2,
+	.epsize = 64,
+};
 #endif
 
 
@@ -2181,7 +2188,7 @@
 		dev->driver_info->description);
 
 #ifdef CONFIG_USB_ZAURUS
-	if (dev->driver_info == &zaurus_info) {
+	if (dev->driver_info == &zaurus_sl5x00_info) {
 		int	status;
 		status = usb_set_configuration (xdev, 1);
 		devinfo (dev, "set config --> %d", status);
@@ -2302,7 +2309,17 @@
 	.bInterfaceClass	= 0x0a,
 	.bInterfaceSubClass	= 0x00,
 	.bInterfaceProtocol	= 0x00,
-	.driver_info =  (unsigned long) &zaurus_info,
+	.driver_info =  (unsigned long) &zaurus_sl5x00_info,
+},
+{
+	.match_flags	=   USB_DEVICE_ID_MATCH_INT_INFO
+			  | USB_DEVICE_ID_MATCH_DEVICE, 
+	.idVendor		= 0x04DD,
+	.idProduct		= 0x8005,
+	.bInterfaceClass	= 0x02,
+	.bInterfaceSubClass	= 0x0a,
+	.bInterfaceProtocol	= 0x00,
+	.driver_info =  (unsigned long) &zaurus_sla300_info,
 },
 #endif
 
